"""Constants for testing."""

from zecmf.constants import HTTPStatus

# Re-export HTTP status codes for convenience in tests
HTTP_OK = HTTPStatus.OK
HTTP_CREATED = HTTPStatus.CREATED
HTTP_ACCEPTED = HTTPStatus.ACCEPTED
HTTP_NO_CONTENT = HTTPStatus.NO_CONTENT
HTTP_BAD_REQUEST = HTTPStatus.BAD_REQUEST
HTTP_UNAUTHORIZED = HTTPStatus.UNAUTHORIZED
HTTP_FORBIDDEN = HTTPStatus.FORBIDDEN
HTTP_NOT_FOUND = HTTPStatus.NOT_FOUND
HTTP_CONFLICT = HTTPStatus.CONFLICT
HTTP_UNPROCESSABLE_ENTITY = HTTPStatus.UNPROCESSABLE_ENTITY
HTTP_INTERNAL_SERVER_ERROR = HTTPStatus.INTERNAL_SERVER_ERROR
